Crate pubky_homeserver

Crate pubky_homeserver 

Homeserver for Pubky

This crate provides a homeserver for Pubky. It is responsible for handling user authentication, authorization, and other core functionalities.

This crate is part of the Pubky project.

For more information, see the Pubky project.

Modules

quota_config
Quota configuration for the TomlConfig.
storage_config
Opendal config for the TomlConfig.
tracing
Module to initialize tracing logs.

Structs

AdminServer
Admin server
AdminToml
Admin server configuration
AppContext
The application context shared between all components. Think of it as a simple Dependency Injection container.
ClientServer
A Pubky homeserver with ICANN HTTP and Pubky TLS servers.
ConfigToml
The overall application configuration, composed of several subsections.
ConnectionString
A connection string for a postgres database. See https://www.postgresql.org/docs/current/libpq-connect.html#LIBPQ-CONNSTRING-URIS
DefaultQuotasToml
Default bandwidth limits for the rate limiter.
Domain
Validated domain name according to RFC 1123.
DomainPort
A domain and port pair.
HomeserverApp
Homeserver with all bells and whistles. Core + Admin + Metrics servers.
LoggingToml
A config for Homeserver tracing subscriber configuration
MetricsServer
Metrics server
MetricsToml
Metrics server configuration
PersistentDataDir
The data directory for the homeserver.

Enums

AdminServerBuildError
Errors that can occur when building a AdminServer.
AppContextConversionError
Errors that can occur when converting a DataDir to an AppContext.
ClientServerBuildError
Errors that can occur when building a HomeserverCore.
ConfigReadError
Error that can occur when reading a configuration file.
HomeserverAppBuildError
Errors that can occur when building a HomeserverApp.
MetricsServerBuildError
Errors that can occur when building a MetricsServer.
SignupMode
The mode of signup.

Traits

DataDir
A trait for the data directory. Used to abstract the data directory from the rest of the code.