pub enum ConfigReadError {
ConfigFileNotFound(Error),
ConfigFileNotValid(Error),
ConfigMergeError(String),
}Expand description
Error that can occur when reading a configuration file.
Variants
ConfigFileNotFound(Error)
The file did not exist or could not be read.
ConfigFileNotValid(Error)
The TOML was syntactically invalid.
ConfigMergeError(String)
Failed to merge defaults with overrides.