pub struct AdminServer { /* private fields */ }Expand description
Admin server
This server is protected by the admin auth middleware.
When dropped, the server will stop.
Implementations
Sourceimpl AdminServer
impl AdminServer
Sourcepub async fn from_data_dir(
data_dir: PersistentDataDir,
) -> Result<Self, AdminServerBuildError>
pub async fn from_data_dir( data_dir: PersistentDataDir, ) -> Result<Self, AdminServerBuildError>
Create a new admin server from a data directory.
Sourcepub async fn from_data_dir_path(
data_dir_path: PathBuf,
) -> Result<Self, AdminServerBuildError>
pub async fn from_data_dir_path( data_dir_path: PathBuf, ) -> Result<Self, AdminServerBuildError>
Create a new admin server from a data directory path.
Sourcepub async fn start(context: &AppContext) -> Result<Self, AdminServerBuildError>
pub async fn start(context: &AppContext) -> Result<Self, AdminServerBuildError>
Run the admin server.
Sourcepub fn listen_socket(&self) -> SocketAddr
pub fn listen_socket(&self) -> SocketAddr
Get the socket address of the admin server.
Sourcepub async fn create_signup_token(&self) -> Result<String>
pub async fn create_signup_token(&self) -> Result<String>
Create a signup token for the given homeserver.