pub struct ClientServer { /* private fields */ }Expand description
A Pubky homeserver with ICANN HTTP and Pubky TLS servers.
Implementations
Sourceimpl ClientServer
impl ClientServer
Sourcepub async fn start_with_persistent_data_dir_path(
dir_path: PathBuf,
) -> Result<Self, ClientServerBuildError>
pub async fn start_with_persistent_data_dir_path( dir_path: PathBuf, ) -> Result<Self, ClientServerBuildError>
Run the homeserver with configurations from a data directory.
Sourcepub async fn start_with_persistent_data_dir(
dir: PersistentDataDir,
) -> Result<Self, ClientServerBuildError>
pub async fn start_with_persistent_data_dir( dir: PersistentDataDir, ) -> Result<Self, ClientServerBuildError>
Run the homeserver with configurations from a data directory.
Sourcepub async fn start(context: AppContext) -> Result<Self, ClientServerBuildError>
pub async fn start(context: AppContext) -> Result<Self, ClientServerBuildError>
Start homeserver services with the given application context.
Sourcepub fn icann_http_url_string(&self) -> String
pub fn icann_http_url_string(&self) -> String
Get the URL of the icann http server.
Sourcepub fn pubky_tls_dns_url_string(&self) -> String
pub fn pubky_tls_dns_url_string(&self) -> String
Get the URL of the pubky tls server with the Pubky DNS name.
Sourcepub fn pubky_tls_ip_url_ring(&self) -> String
pub fn pubky_tls_ip_url_ring(&self) -> String
Get the URL of the pubky tls server with the Pubky IP address.