pub struct ConnectionString(/* private fields */);Expand description
A connection string for a postgres database. See https://www.postgresql.org/docs/current/libpq-connect.html#LIBPQ-CONNSTRING-URIS
Implementations
Sourceimpl ConnectionString
impl ConnectionString
Sourcepub fn new(con_string: &str) -> Result<Self>
pub fn new(con_string: &str) -> Result<Self>
Create a new connection string from a string. This function validates that the connection string is a postgres connection string.
Sourcepub fn database_name(&self) -> &str
pub fn database_name(&self) -> &str
Get the database name For postgres, this is the database name directly
Sourcepub fn set_database_name(&mut self, db_name: &str)
pub fn set_database_name(&mut self, db_name: &str)
Set the database name, clearing any dbname query parameter that would
otherwise override the path. See
https://www.postgresql.org/docs/current/libpq-connect.html#LIBPQ-CONNSTRING-URIS