pub struct HomeserverApp { /* private fields */ }Expand description
Homeserver with all bells and whistles. Core + Admin + Metrics servers.
When dropped, the homeserver will stop.
Implementations
Sourceimpl HomeserverApp
impl HomeserverApp
Sourcepub async fn start_with_persistent_data_dir_path(
dir_path: PathBuf,
) -> Result<Self>
pub async fn start_with_persistent_data_dir_path( dir_path: PathBuf, ) -> Result<Self>
Run the homeserver with configurations from a data directory.
Sourcepub async fn start_with_persistent_data_dir(
dir: PersistentDataDir,
) -> Result<Self>
pub async fn start_with_persistent_data_dir( dir: PersistentDataDir, ) -> Result<Self>
Run the homeserver with configurations from a data directory.
Sourcepub async fn start(context: AppContext) -> Result<Self>
pub async fn start(context: AppContext) -> Result<Self>
Run a Homeserver
Sourcepub fn client_server(&self) -> &ClientServer
pub fn client_server(&self) -> &ClientServer
Get the core of the homeserver app.
Sourcepub fn admin_server(&self) -> Option<&AdminServer>
pub fn admin_server(&self) -> Option<&AdminServer>
Get the admin server of the homeserver app.
Sourcepub fn metrics_server(&self) -> Option<&MetricsServer>
pub fn metrics_server(&self) -> Option<&MetricsServer>
Get the metrics server of the homeserver app.
Sourcepub fn public_key(&self) -> PublicKey
pub fn public_key(&self) -> PublicKey
Returns the public_key of this server.
Sourcepub fn icann_http_url(&self) -> Url
pub fn icann_http_url(&self) -> Url
Returns the https://<server public key> url