MetricsServer

Struct MetricsServer 

pub struct MetricsServer { /* private fields */ }
Metrics server

This server exposes Prometheus metrics on a separate port. It should be isolated from the public network and only accessible to monitoring systems.

When dropped, the server will stop.

Implementations

Source

impl MetricsServer

pub async fn start( context: &AppContext, ) -> Result<Self, MetricsServerBuildError>

Run the metrics server.

pub fn listen_socket(&self) -> SocketAddr

Get the socket address the metrics server is listening on.