pub struct PersistentDataDir { /* private fields */ }Expand description
The data directory for the homeserver.
This is the directory that will store the homeservers data.
Implementations
Sourceimpl PersistentDataDir
impl PersistentDataDir
Sourcepub fn new(path: PathBuf) -> Self
pub fn new(path: PathBuf) -> Self
Creates a new data directory.
path will be expanded to the home directory if it starts with “~”.
Sourcepub fn get_config_file_path(&self) -> PathBuf
pub fn get_config_file_path(&self) -> PathBuf
Returns the config file path in this directory.
Sourcepub fn get_secret_file_path(&self) -> PathBuf
pub fn get_secret_file_path(&self) -> PathBuf
Returns the path to the secret file.