Homeserver for Pubky
This crate provides a homeserver for Pubky. It is responsible for handling user authentication, authorization, and other core functionalities.
This crate is part of the Pubky project.
For more information, see the Pubky project.
Modules
- quota_
config - Quota configuration for the TomlConfig.
- storage_
config - Opendal config for the TomlConfig.
- tracing
- Module to initialize tracing logs.
Structs
- Admin
Server - Admin server
- Admin
Toml - Admin server configuration
- AppContext
- The application context shared between all components. Think of it as a simple Dependency Injection container.
- Client
Server - A Pubky homeserver with ICANN HTTP and Pubky TLS servers.
- Config
Toml - The overall application configuration, composed of several subsections.
- Connection
String - A connection string for a postgres database. See https://www.postgresql.org/docs/current/libpq-connect.html#LIBPQ-CONNSTRING-URIS
- Default
Quotas Toml - Default bandwidth limits for the rate limiter.
- Domain
- Validated domain name according to RFC 1123.
- Domain
Port - A domain and port pair.
- Homeserver
App - Homeserver with all bells and whistles. Core + Admin + Metrics servers.
- Logging
Toml - A config for Homeserver tracing subscriber configuration
- Metrics
Server - Metrics server
- Metrics
Toml - Metrics server configuration
- Persistent
Data Dir - The data directory for the homeserver.
Enums
- Admin
Server Build Error - Errors that can occur when building a
AdminServer. - AppContext
Conversion Error - Errors that can occur when converting a
DataDirto anAppContext. - Client
Server Build Error - Errors that can occur when building a
HomeserverCore. - Config
Read Error - Error that can occur when reading a configuration file.
- Homeserver
AppBuild Error - Errors that can occur when building a
HomeserverApp. - Metrics
Server Build Error - Errors that can occur when building a
MetricsServer. - Signup
Mode - The mode of signup.
Traits
- DataDir
- A trait for the data directory. Used to abstract the data directory from the rest of the code.