pub struct MetricsServer { /* private fields */ }Expand description
Metrics server
This server exposes Prometheus metrics on a separate port. It should be isolated from the public network and only accessible to monitoring systems.
When dropped, the server will stop.
Implementations
Sourceimpl MetricsServer
impl MetricsServer
Sourcepub async fn start(
context: &AppContext,
) -> Result<Self, MetricsServerBuildError>
pub async fn start( context: &AppContext, ) -> Result<Self, MetricsServerBuildError>
Run the metrics server.
Sourcepub fn listen_socket(&self) -> SocketAddr
pub fn listen_socket(&self) -> SocketAddr
Get the socket address the metrics server is listening on.